diff --git a/release.sh b/release.sh
index bc097f26d29648d50b59cbcbc86b22df3dd18615..27ee8568d0d371003c9f948f7266deaa4463befb 100755
--- a/release.sh
+++ b/release.sh
@@ -7,13 +7,13 @@ echo "Current version: $current"
 if [[ $1 =~ ^[0-9]+.[0-9]+.[0-9]+[0-9a-z]*$ ]]; then
   # update version in duniterpy
   sed -i "s/__version__ = \"$current\"/__version__ = \"$1\"/g" duniterpy/__init__.py
-  # update version in setup.py
-  sed -i "s/version=\"$current\",/version=\"$1\",/" setup.py
+  # update version in pyproject.toml
+  poetry version "$1"
   # update version in documentation configuration
   sed -i "s/version = '$current'/version = '$1'/g" docs/conf.py
   sed -i "s/release = '$current'/release = '$1'/g" docs/conf.py
   # commit changes and add version tag
-  git commit setup.py duniterpy/__init__.py docs/conf.py -m "$1"
+  git commit pyproject.toml duniterpy/__init__.py docs/conf.py -m "$1"
   git tag "$1" -a -m "$1"
 else
   echo "Wrong version format"